@@ -13,7 +13,7 @@ class CONFIG:
     # Enable deterministic cuda flag and use seeds everywhere (static or based on features of the dataset)
     DETERMINISTIC = True
     SELFAWARE = True
-    HELPER_MIXERS = False#True
+    HELPER_MIXERS = True
     FORCE_HELPER_MIXERS = False
     ENABLE_DROPOUT = True
 
@@ -29,3 +29,5 @@ class CONFIG:
         ,'batch_loss': False
         ,'network_heatmap': False
     }
+
+    QUANTILES = [0.05,0.95]
